@@ -14,6 +14,7 @@ def render_markdown(wiki_page):
     '''Render the Markdown from the wiki page provided. Assumes path exists.'''
     with open(wiki_page) as wiki_file:
         text = wiki_file.read()
-        extensions = [wiki_link_extension, 'fenced_code', 'codehilite']
+        extensions = [wiki_link_extension, 'fenced_code', 'codehilite',
+                      'toc(anchorlink=True)']
         return markdown.markdown(text, safe_mode='escape',
                                  extensions=extensions, output_format='html5')
